/*  Copyright (C) 2023 Chair of Aircraft Design, Technical University Munich
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * @file main.cpp
 * @brief Report generator.
 * @version 2.0.0
 * @date 2024-12-20
 */

 /* === Includes === */
#include "report_generator.h"
#include "toolinfo.h"

int main(int argc, char** argv)
{
    /* Add exception handling since the constructor of the module can throw. */
    try {
        ReportGenerator reporting_module(argc, argv, TOOL_NAME, TOOL_VERSION);
        return reporting_module.execute();
    }
    catch (const std::string& error) {
        std::cerr << error << std::endl;
    }
    catch (const std::exception& error) {
        std::cerr << error.what() << std::endl;
    }
    catch (...) {
        std::cerr << "Unknown error occurred." << std::endl;
    }
    return EXIT_FAILURE;
}
